@@ -18,7 +18,8 @@ from . import snowball
 from .exc import ValidationError, PrefixError
 
 
-RETRY_LIMIT = 3
+RETRY_LIMIT = 5
+RETRY_BACKOFF_FACTOR = 0.2
 
 logger = logging.getLogger(__name__)
 
@@ -212,7 +213,7 @@ class Database(object):
                         '%s after %s retries, failing.', e, tries)
                     raise
                 logger.info('%s: after %s retries, retrying', e, tries)
-                time.sleep(tries * .1)
+                time.sleep(tries * RETRY_BACKOFF_FACTOR)
                 self.reopen(refresh=refresh)
                 tries += 1
 
@@ -1008,17 +1009,22 @@ class Database(object):
             limit = int(self.backend.get_doccount() * klimit)
 
         if xapian_version <= (1, 2, 4):
-            eset = enq.get_eset(limit, rset,
-                                enq.INCLUDE_QUERY_TERMS,
-                                1.0, decider)
+            op = lambda: enq.get_eset(
+                limit, rset,
+                enq.INCLUDE_QUERY_TERMS,
+                1.0, decider)
         elif xapian_version == (1, 2, 5):
-            eset = enq.get_eset(limit, rset,
-                                enq.INCLUDE_QUERY_TERMS,
-                                1.0, decider, -3)
+            op = lambda: enq.get_eset(
+                limit, rset,
+                enq.INCLUDE_QUERY_TERMS,
+                1.0, decider, -3)
         else:
-            eset = enq.get_eset(limit, rset,
-                                enq.INCLUDE_QUERY_TERMS,
-                                1.0, decider, 0)
+            op = lambda: enq.get_eset(
+                limit, rset,
+                enq.INCLUDE_QUERY_TERMS,
+                1.0, decider, 0)
+
+        eset = self.retry_if_modified(op, retry_limit)
 
         for item in eset.items:
             val = item[0].decode('utf8')
