@@ -1,3 +1,4 @@
+import logging
 import unicodedata
 import translitcodec
 
@@ -11,6 +12,8 @@ from .exc import (
     InvalidTermError,
     )
 
+logger = logging.getLogger(__name__)
+
 def _schema_name(schema):
     return "%s.%s" % (schema.__module__, schema.__class__.__name__)
 
@@ -47,6 +50,11 @@ class Schema(schema.Form):
     for facets.
     """
 
+    ignore_invalid_terms = False
+    """When True, invalid terms will be skipped with a warning.
+    When False (default) an invalid term in a document raises InvalidTermError.
+    """
+
     def update_by_object(self, obj):
         """Updates fields with an object's attributes.
 
@@ -111,7 +119,14 @@ class Schema(schema.Form):
                 else:
                     raise TypeError("Unknown element %s" % el)
 
-                value = handler(el)
+                value = None
+                try:
+                    value = handler(el)
+                except InvalidTermError, e:
+                    if self.ignore_invalid_terms:
+                        logger.warning('Invalid term ignored: %r' % el)
+                    else:
+                        raise
 
                 if value is not None:
                     if el.facet:
